@@ -1,14 +1,14 @@
 #include <stdio.h>
 #include <fcntl.h>
-#include <ndbm.h>
+#include <gdbm.h>
 
 main(int argc, char *argv[])
 {
-    DBM *dbp;
+    GDBM_FILE dbp;
     datum kdat, vdat;
     
 
-    dbp = dbm_open(argv[1], O_RDWR+O_CREAT, 0777);
+    dbp = gdbm_open(argv[1], 64, O_RDWR+O_CREAT, 0777, NULL);
     if (dbp == NULL)
     {
 	perror("dbadd: dbm_open");
@@ -21,13 +21,13 @@ main(int argc, char *argv[])
     vdat.dsize = strlen(argv[3]);
     vdat.dptr = argv[3];
     
-    if (dbm_store(dbp, kdat, vdat, DBM_REPLACE) < 0)
+    if (gdbm_store(dbp, kdat, vdat, GDBM_REPLACE) < 0)
     {
 	perror("dbadd: dbm_store");
-	dbm_close(dbp);
+	gdbm_close(dbp);
 	exit(1);
     }
     
-    dbm_close(dbp);
+    gdbm_close(dbp);
     exit(0);
 }
